/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { t } from '@superset-ui/core';
import {

  getStandardizedControls,
  sharedControls,
  sections } from
'@superset-ui/chart-controls';
import { headerFontSize, subheaderFontSize } from '../sharedControls';
import { ColorSchemeEnum } from './types';

const config = {
  controlPanelSections: [
  {
    label: t('Query'),
    expanded: true,
    controlSetRows: [
    ['metric'],
    ['adhoc_filters'],
    [
    {
      name: 'row_limit',
      config: sharedControls.row_limit
    }]]


  },
  {
    label: t('Chart Options'),
    expanded: true,
    controlSetRows: [
    ['y_axis_format'],
    [
    {
      name: 'percentDifferenceFormat',
      config: {
        ...sharedControls.y_axis_format,
        label: t('Percent Difference format')
      }
    }],

    ['currency_format'],
    [
    {
      ...headerFontSize,
      config: { ...headerFontSize.config, default: 0.2 }
    }],

    [
    {
      ...subheaderFontSize,
      config: {
        ...subheaderFontSize.config,
        default: 0.125,
        label: t('Comparison font size')
      }
    }],

    [
    {
      name: 'comparison_color_enabled',
      config: {
        type: 'CheckboxControl',
        label: t('Add color for positive/negative change'),
        renderTrigger: true,
        default: false,
        description: t('Add color for positive/negative change')
      }
    }],

    [
    {
      name: 'comparison_color_scheme',
      config: {
        type: 'SelectControl',
        label: t('color scheme for comparison'),
        default: ColorSchemeEnum.Green,
        renderTrigger: true,
        choices: [
        [ColorSchemeEnum.Green, 'Green for increase, red for decrease'],
        [ColorSchemeEnum.Red, 'Red for increase, green for decrease']],

        visibility: ({ controls }) => {var _controls$comparison_;return (
            (controls == null ? void 0 : (_controls$comparison_ = controls.comparison_color_enabled) == null ? void 0 : _controls$comparison_.value) === true);},
        description: t(
          'Adds color to the chart symbols based on the positive or ' +
          'negative change from the comparison value.'
        )
      }
    }]]


  },
  sections.timeComparisonControls({
    multi: false,
    showCalculationType: false,
    showFullChoices: false
  })],

  controlOverrides: {
    y_axis_format: {
      label: t('Number format')
    }
  },
  formDataOverrides: (formData) => ({
    ...formData,
    metric: getStandardizedControls().shiftMetric()
  })
};

export default config;
//# sourceMappingURL=controlPanel.js.map