/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { t } from '@superset-ui/core';
import {

  ControlSubSectionHeader,
  D3_FORMAT_DOCS,
  D3_NUMBER_FORMAT_DESCRIPTION_VALUES_TEXT,
  D3_FORMAT_OPTIONS,
  D3_TIME_FORMAT_OPTIONS,
  getStandardizedControls } from
'@superset-ui/chart-controls';
import { DEFAULT_FORM_DATA } from './types';import { jsx as _jsx } from "@emotion/react/jsx-runtime";

const { labelType, numberFormat, showLabels, showUpperLabels, dateFormat } =
DEFAULT_FORM_DATA;

const config = {
  controlPanelSections: [
  {
    label: t('Query'),
    expanded: true,
    controlSetRows: [
    ['groupby'],
    ['metric'],
    ['row_limit'],
    ['sort_by_metric'],
    ['adhoc_filters']]

  },
  {
    label: t('Chart Options'),
    expanded: true,
    controlSetRows: [
    ['color_scheme'],
    [_jsx(ControlSubSectionHeader, { children: t('Labels') })],
    [
    {
      name: 'show_labels',
      config: {
        type: 'CheckboxControl',
        label: t('Show Labels'),
        renderTrigger: true,
        default: showLabels,
        description: t('Whether to display the labels.')
      }
    }],

    [
    {
      name: 'show_upper_labels',
      config: {
        type: 'CheckboxControl',
        label: t('Show Upper Labels'),
        renderTrigger: true,
        default: showUpperLabels,
        description: t('Show labels when the node has children.')
      }
    }],

    [
    {
      name: 'label_type',
      config: {
        type: 'SelectControl',
        label: t('Label Type'),
        default: labelType,
        renderTrigger: true,
        choices: [
        ['Key', t('Key')],
        ['value', t('Value')],
        ['key_value', t('Category and Value')]],

        description: t('What should be shown on the label?')
      }
    }],

    [
    {
      name: 'number_format',
      config: {
        type: 'SelectControl',
        freeForm: true,
        label: t('Number format'),
        renderTrigger: true,
        default: numberFormat,
        choices: D3_FORMAT_OPTIONS,
        description: `${D3_FORMAT_DOCS} ${D3_NUMBER_FORMAT_DESCRIPTION_VALUES_TEXT}`
      }
    }],

    ['currency_format'],
    [
    {
      name: 'date_format',
      config: {
        type: 'SelectControl',
        freeForm: true,
        label: t('Date format'),
        renderTrigger: true,
        choices: D3_TIME_FORMAT_OPTIONS,
        default: dateFormat,
        description: D3_FORMAT_DOCS
      }
    }]]


  }],

  formDataOverrides: (formData) => ({
    ...formData,
    metric: getStandardizedControls().shiftMetric(),
    groupby: getStandardizedControls().popAllColumns()
  })
};

export default config;
//# sourceMappingURL=controlPanel.js.map