import _sumBy from "lodash/sumBy";import _orderBy from "lodash/orderBy";import _minBy from "lodash/minBy";import _meanBy from "lodash/meanBy";import _maxBy from "lodash/maxBy";import _isEmpty from "lodash/isEmpty"; /* eslint-disable no-underscore-dangle */
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import {
  AxisType,



  DTTM_ALIAS,
  ensureIsArray,
  GenericDataType,

  normalizeTimestamp,
  NumberFormats,
  NumberFormatter } from



'@superset-ui/core';
import { SortSeriesType } from '@superset-ui/chart-controls';
import { format } from 'echarts/core';



import {
  NULL_STRING,
  StackControlsValue,
  TIMESERIES_CONSTANTS } from
'../constants';
import {
  EchartsTimeseriesSeriesType,
  LegendOrientation } from


'../types';
import { defaultLegendPadding } from '../defaults';

function isDefined(value) {
  return value !== undefined && value !== null;
}

export function extractDataTotalValues(
data,
opts)








{
  const totalStackedValues = [];
  const thresholdValues = [];
  const { stack, percentageThreshold, xAxisCol, legendState } = opts;
  if (stack) {
    data.forEach((datum) => {
      const values = Object.keys(datum).reduce((prev, curr) => {
        if (curr === xAxisCol) {
          return prev;
        }
        if (legendState && !legendState[curr]) {
          return prev;
        }
        const value = datum[curr] || 0;
        return prev + value;
      }, 0);
      totalStackedValues.push(values);
      thresholdValues.push((percentageThreshold || 0) / 100 * values);
    });
  }
  return {
    totalStackedValues,
    thresholdValues
  };
}

export function extractShowValueIndexes(
series,
opts)





{
  const showValueIndexes = [];
  const { legendState, stack, isHorizontal, onlyTotal } = opts;
  if (stack) {
    series.forEach((entry, seriesIndex) => {
      const { data = [] } = entry;
      data.forEach((datum, dataIndex) => {
        if (entry.id && legendState && !legendState[entry.id]) {
          return;
        }
        if (!onlyTotal && datum[isHorizontal ? 0 : 1] !== null) {
          showValueIndexes[dataIndex] = seriesIndex;
        }
        if (onlyTotal) {
          if (datum[isHorizontal ? 0 : 1] > 0) {
            showValueIndexes[dataIndex] = seriesIndex;
          }
          if (
          !showValueIndexes[dataIndex] &&
          datum[isHorizontal ? 0 : 1] !== null)
          {
            showValueIndexes[dataIndex] = seriesIndex;
          }
        }
      });
    });
  }
  return showValueIndexes;
}

export function sortAndFilterSeries(
rows,
xAxis,
extraMetricLabels,
sortSeriesType,
sortSeriesAscending)
{
  const seriesNames = Object.keys(rows[0]).
  filter((key) => key !== xAxis).
  filter((key) => !extraMetricLabels.includes(key));

  let aggregator;

  switch (sortSeriesType) {
    case SortSeriesType.Sum:
      aggregator = (name) => ({ name, value: _sumBy(rows, name) });
      break;
    case SortSeriesType.Min:
      aggregator = (name) => {var _minBy2;return { name, value: (_minBy2 = _minBy(rows, name)) == null ? void 0 : _minBy2[name] };};
      break;
    case SortSeriesType.Max:
      aggregator = (name) => {var _maxBy2;return { name, value: (_maxBy2 = _maxBy(rows, name)) == null ? void 0 : _maxBy2[name] };};
      break;
    case SortSeriesType.Avg:
      aggregator = (name) => ({ name, value: _meanBy(rows, name) });
      break;
    default:
      aggregator = (name) => ({ name, value: name.toLowerCase() });
      break;
  }

  const sortedValues = seriesNames.map(aggregator);

  return _orderBy(
    sortedValues,
    ['value'],
    [sortSeriesAscending ? 'asc' : 'desc']
  ).map(({ name }) => name);
}

export function sortRows(
rows,
totalStackedValues,
xAxis,
xAxisSortSeries,
xAxisSortSeriesAscending)
{
  const sortedRows = rows.map((row, idx) => {
    let sortKey = '';
    let aggregate;
    let entries = 0;
    Object.entries(row).forEach(([key, value]) => {
      const isValueDefined = isDefined(value);
      if (key === xAxis) {
        sortKey = value;
      }
      if (
      xAxisSortSeries === SortSeriesType.Name ||
      typeof value !== 'number')
      {
        return;
      }

      if (!(xAxisSortSeries === SortSeriesType.Avg && !isValueDefined)) {
        entries += 1;
      }

      switch (xAxisSortSeries) {
        case SortSeriesType.Avg:
        case SortSeriesType.Sum:
          if (aggregate === undefined) {
            aggregate = value;
          } else {
            aggregate += value;
          }
          break;
        case SortSeriesType.Min:
          aggregate =
          aggregate === undefined || isValueDefined && value < aggregate ?
          value :
          aggregate;
          break;
        case SortSeriesType.Max:
          aggregate =
          aggregate === undefined || isValueDefined && value > aggregate ?
          value :
          aggregate;
          break;
        default:
          break;
      }
    });
    if (
    xAxisSortSeries === SortSeriesType.Avg &&
    entries > 0 &&
    aggregate !== undefined)
    {
      aggregate /= entries;
    }

    const value =
    xAxisSortSeries === SortSeriesType.Name ?
    typeof sortKey === 'string' ?
    sortKey.toLowerCase() :
    sortKey :
    aggregate;

    return {
      key: sortKey,
      value,
      row,
      totalStackedValue: totalStackedValues[idx]
    };
  });

  return _orderBy(
    sortedRows,
    ['value'],
    [xAxisSortSeriesAscending ? 'asc' : 'desc']
  ).map(({ row, totalStackedValue }) => ({ row, totalStackedValue }));
}

export function extractSeries(
data,
opts =











{})
{
  const {
    fillNeighborValue,
    xAxis = DTTM_ALIAS,
    extraMetricLabels = [],
    removeNulls = false,
    stack = false,
    totalStackedValues = [],
    isHorizontal = false,
    sortSeriesType,
    sortSeriesAscending,
    xAxisSortSeries,
    xAxisSortSeriesAscending
  } = opts;
  if (data.length === 0) return [[], [], undefined];
  const rows = data.map((datum) => ({
    ...datum,
    [xAxis]: datum[xAxis]
  }));
  const sortedSeries = sortAndFilterSeries(
    rows,
    xAxis,
    extraMetricLabels,
    sortSeriesType,
    sortSeriesAscending
  );
  const sortedRows =
  isDefined(xAxisSortSeries) && isDefined(xAxisSortSeriesAscending) ?
  sortRows(
    rows,
    totalStackedValues,
    xAxis,
    xAxisSortSeries,
    xAxisSortSeriesAscending
  ) :
  rows.map((row, idx) => ({
    row,
    totalStackedValue: totalStackedValues[idx]
  }));

  let minPositiveValue;
  const finalSeries = sortedSeries.map((name) => ({
    id: name,
    name,
    data: sortedRows.
    map(({ row, totalStackedValue }, idx) => {var _rows, _rows2;
      const currentValue = row[name];
      if (
      typeof currentValue === 'number' &&
      currentValue > 0 && (
      minPositiveValue === undefined || minPositiveValue > currentValue))
      {
        minPositiveValue = currentValue;
      }
      const isNextToDefinedValue =
      isDefined((_rows = rows[idx - 1]) == null ? void 0 : _rows[name]) || isDefined((_rows2 = rows[idx + 1]) == null ? void 0 : _rows2[name]);
      const isFillNeighborValue =
      !isDefined(currentValue) &&
      isNextToDefinedValue &&
      fillNeighborValue !== undefined;
      let value = currentValue;
      if (isFillNeighborValue) {
        value = fillNeighborValue;
      } else if (
      stack === StackControlsValue.Expand &&
      totalStackedValue !== undefined)
      {
        value = (value || 0) / totalStackedValue;
      }
      return [row[xAxis], value];
    }).
    filter((obs) => !removeNulls || obs[0] !== null && obs[1] !== null).
    map((obs) => isHorizontal ? [obs[1], obs[0]] : obs)
  }));
  return [
  finalSeries,
  sortedRows.map(({ totalStackedValue }) => totalStackedValue),
  minPositiveValue];

}

export function formatSeriesName(
name,
{
  numberFormatter,
  timeFormatter,
  coltype




} = {})
{
  if (name === undefined || name === null) {
    return NULL_STRING;
  }
  if (typeof name === 'boolean') {
    return name.toString();
  }
  if (name instanceof Date || coltype === GenericDataType.Temporal) {
    const normalizedName =
    typeof name === 'string' ? normalizeTimestamp(name) : name;
    const d =
    normalizedName instanceof Date ?
    normalizedName :
    new Date(normalizedName);

    return timeFormatter ? timeFormatter(d) : d.toISOString();
  }
  if (typeof name === 'number') {
    return numberFormatter ? numberFormatter(name) : name.toString();
  }
  return name;
}

export const getColtypesMapping = ({
  coltypes = [],
  colnames = []
}) =>



colnames.reduce(
  (accumulator, item, index) => ({ ...accumulator, [item]: coltypes[index] }),
  {}
);

export function extractGroupbyLabel({
  datum = {},
  groupby,
  numberFormatter,
  timeFormatter,
  coltypeMapping = {}






}) {
  return ensureIsArray(groupby).
  map((val) =>
  formatSeriesName(datum[val], {
    numberFormatter,
    timeFormatter,
    ...(coltypeMapping[val] && { coltype: coltypeMapping[val] })
  })
  ).
  join(', ');
}

export function getLegendProps(
type,
orientation,
show,
theme,
zoomable = false,
legendState)
{
  const legend = {
    orient: [LegendOrientation.Top, LegendOrientation.Bottom].includes(
      orientation
    ) ?
    'horizontal' :
    'vertical',
    show,
    type,
    selected: legendState,
    selector: ['all', 'inverse'],
    selectorLabel: {
      fontFamily: theme.typography.families.sansSerif,
      fontSize: theme.typography.sizes.s,
      color: theme.colors.grayscale.base,
      borderColor: theme.colors.grayscale.base
    }
  };
  switch (orientation) {
    case LegendOrientation.Left:
      legend.left = 0;
      break;
    case LegendOrientation.Right:
      legend.right = 0;
      legend.top = zoomable ? TIMESERIES_CONSTANTS.legendRightTopOffset : 0;
      break;
    case LegendOrientation.Bottom:
      legend.bottom = 0;
      break;
    case LegendOrientation.Top:
    default:
      legend.top = 0;
      legend.right = zoomable ? TIMESERIES_CONSTANTS.legendTopRightOffset : 0;
      break;
  }
  return legend;
}

export function getChartPadding(
show,
orientation,
margin,
padding,
isHorizontal)





{
  let legendMargin;
  if (!show) {
    legendMargin = 0;
  } else if (
  margin === null ||
  margin === undefined ||
  typeof margin === 'string')
  {
    legendMargin = defaultLegendPadding[orientation];
  } else {
    legendMargin = margin;
  }

  const { bottom = 0, left = 0, right = 0, top = 0 } = padding || {};

  if (isHorizontal) {
    return {
      left:
      left + (orientation === LegendOrientation.Bottom ? legendMargin : 0),
      right:
      right + (orientation === LegendOrientation.Right ? legendMargin : 0),
      top: top + (orientation === LegendOrientation.Top ? legendMargin : 0),
      bottom:
      bottom + (orientation === LegendOrientation.Left ? legendMargin : 0)
    };
  }

  return {
    left: left + (orientation === LegendOrientation.Left ? legendMargin : 0),
    right: right + (orientation === LegendOrientation.Right ? legendMargin : 0),
    top: top + (orientation === LegendOrientation.Top ? legendMargin : 0),
    bottom:
    bottom + (orientation === LegendOrientation.Bottom ? legendMargin : 0)
  };
}

export function dedupSeries(series) {
  const counter = new Map();
  return series.map((row) => {
    let { id } = row;
    if (id === undefined) return row;
    id = String(id);
    const count = counter.get(id) || 0;
    const suffix = count > 0 ? ` (${count})` : '';
    counter.set(id, count + 1);
    return {
      ...row,
      id: `${id}${suffix}`
    };
  });
}

export function sanitizeHtml(text) {
  return format.encodeHTML(text);
}

export function getAxisType(
stack,
forceCategorical,
dataType)
{
  if (forceCategorical) {
    return AxisType.Category;
  }
  if (dataType === GenericDataType.Temporal) {
    return AxisType.Time;
  }
  if (dataType === GenericDataType.Numeric && !stack) {
    return AxisType.Value;
  }
  return AxisType.Category;
}

export function getOverMaxHiddenFormatter(
config =


{})
{
  const { max, formatter } = config;
  // Only apply this logic if there's a MAX set in the controls
  const shouldHideIfOverMax = !!max || max === 0;

  return new NumberFormatter({
    formatFunc: (value) =>
    `${
    shouldHideIfOverMax && value > max ?
    '' :
    (formatter == null ? void 0 : formatter.format(value)) || value}`,

    id: NumberFormats.OVER_MAX_HIDDEN
  });
}

export function calculateLowerLogTick(minPositiveValue) {
  const logBase10 = Math.floor(Math.log10(minPositiveValue));
  return Math.pow(10, logBase10);
}







export function getMinAndMaxFromBounds(
axisType,
truncateAxis,
min,
max,
seriesType)
{
  if (axisType === AxisType.Value && truncateAxis) {
    const ret = {};
    if (seriesType === EchartsTimeseriesSeriesType.Bar) {
      ret.scale = true;
    }
    if (min !== undefined) {
      ret.min = min;
    } else if (seriesType !== EchartsTimeseriesSeriesType.Bar) {
      ret.min = 'dataMin';
    }
    if (max !== undefined) {
      ret.max = max;
    } else if (seriesType !== EchartsTimeseriesSeriesType.Bar) {
      ret.max = 'dataMax';
    }
    return ret;
  }
  return {};
}

/**
 * Returns the stackId used in stacked series.
 * It will return the defaultId if the chart is not using time comparison.
 * If time comparison is used, it will return the time comparison value as the stackId
 * if the name includes the time comparison value.
 *
 * @param {string} defaultId The default stackId.
 * @param {string[]} timeCompare The time comparison values.
 * @param {string | number} name The name of the serie.
 *
 * @returns {string} The stackId.
 */
export function getTimeCompareStackId(
defaultId,
timeCompare,
name)
{
  if (_isEmpty(timeCompare)) {
    return defaultId;
  }
  // Each timeCompare is its own stack so it doesn't stack on top of original ones
  return (
    timeCompare.find((value) => {
      if (typeof name === 'string') {
        // offset is represented as <offset>, group by list
        return (
          name.includes(`${value},`) ||
          // offset is represented as <metric>__<offset>
          name.includes(`__${value}`));

      }
      return name == null ? void 0 : name.toString().includes(value);
    }) || defaultId);

}

const TOOLTIP_SERIES_KEY = 'seriesId';
export function extractTooltipKeys(
forecastValue,
yIndex,
richTooltip,
tooltipSortByMetric)
{
  if (richTooltip && tooltipSortByMetric) {
    return forecastValue.
    slice().
    sort((a, b) => b.data[yIndex] - a.data[yIndex]).
    map((value) => value[TOOLTIP_SERIES_KEY]);
  }
  if (richTooltip) {
    return forecastValue.map((s) => s[TOOLTIP_SERIES_KEY]);
  }
  return [forecastValue[0][TOOLTIP_SERIES_KEY]];
}
//# sourceMappingURL=series.js.map