import { CategoricalColorNamespace, NumberFormats, getColumnLabel, getMetricLabel, getNumberFormatter, tooltipHtml, } from '@superset-ui/core';
import { getDefaultTooltip } from '../utils/tooltip';
import { getPercentFormatter } from '../utils/formatters';
export default function transformProps(chartProps) {
    const refs = {};
    const { formData, height, hooks, queriesData, width } = chartProps;
    const { onLegendStateChanged } = hooks;
    const { colorScheme, metric, source, target, sliceId } = formData;
    const { data } = queriesData[0];
    const colorFn = CategoricalColorNamespace.getScale(colorScheme);
    const metricLabel = getMetricLabel(metric);
    const valueFormatter = getNumberFormatter(NumberFormats.FLOAT_2_POINT);
    const percentFormatter = getPercentFormatter(NumberFormats.PERCENT_2_POINT);
    const links = [];
    const set = new Set();
    data.forEach(datum => {
        const sourceName = String(datum[getColumnLabel(source)]);
        const targetName = String(datum[getColumnLabel(target)]);
        const value = datum[metricLabel];
        set.add(sourceName);
        set.add(targetName);
        links.push({
            source: sourceName,
            target: targetName,
            value,
        });
    });
    const seriesData = Array.from(set).map(name => ({
        name,
        itemStyle: {
            color: colorFn(name, sliceId),
        },
    }));
    // stores a map with the total values for each node considering the links
    const nodeValues = new Map();
    links.forEach(link => {
        const { source, target, value } = link;
        const sourceValue = nodeValues.get(source) || 0;
        const targetValue = nodeValues.get(target) || 0;
        nodeValues.set(source, sourceValue + value);
        nodeValues.set(target, targetValue + value);
    });
    const tooltipFormatter = (params) => {
        const { name, data } = params;
        const value = params.value;
        const rows = [[metricLabel, valueFormatter.format(value)]];
        const { source, target } = data;
        if (source && target) {
            rows.push([
                `% (${source})`,
                percentFormatter.format(value / nodeValues.get(source)),
            ]);
            rows.push([
                `% (${target})`,
                percentFormatter.format(value / nodeValues.get(target)),
            ]);
        }
        return tooltipHtml(rows, name);
    };
    const echartOptions = {
        series: {
            animation: false,
            data: seriesData,
            lineStyle: {
                color: 'source',
            },
            links,
            type: 'sankey',
        },
        tooltip: {
            ...getDefaultTooltip(refs),
            formatter: tooltipFormatter,
        },
    };
    return {
        refs,
        formData,
        width,
        height,
        echartOptions,
        onLegendStateChanged,
    };
}
//# sourceMappingURL=transformProps.js.map