/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { t, AnnotationType, Behavior } from '@superset-ui/core';
import buildQuery from '../buildQuery';
import controlPanel from './controlPanel';
import transformProps from '../transformProps';
import thumbnail from './images/thumbnail.png';
import example1 from './images/Area1.png';
import { EchartsChartPlugin } from '../../types';
const areaTransformProps = (chartProps) => transformProps({
    ...chartProps,
    formData: { ...chartProps.formData, area: true },
});
export default class EchartsAreaChartPlugin extends EchartsChartPlugin {
    constructor() {
        super({
            buildQuery,
            controlPanel,
            loadChart: () => import('../EchartsTimeseries'),
            metadata: {
                behaviors: [
                    Behavior.InteractiveChart,
                    Behavior.DrillToDetail,
                    Behavior.DrillBy,
                ],
                category: t('Evolution'),
                credits: ['https://echarts.apache.org'],
                description: t('Area charts are similar to line charts in that they represent variables with the same scale, but area charts stack the metrics on top of each other.'),
                exampleGallery: [{ url: example1 }],
                supportedAnnotationTypes: [
                    AnnotationType.Event,
                    AnnotationType.Formula,
                    AnnotationType.Interval,
                    AnnotationType.Timeseries,
                ],
                name: t('Area Chart'),
                tags: [
                    t('ECharts'),
                    t('Predictive'),
                    t('Advanced-Analytics'),
                    t('Time'),
                    t('Line'),
                    t('Transformable'),
                    t('Stacked'),
                    t('Featured'),
                ],
                thumbnail,
            },
            transformProps: areaTransformProps,
        });
    }
}
//# sourceMappingURL=index.js.map