/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { AnnotationData, AxisType, CategoricalColorScale, EventAnnotationLayer, FilterState, FormulaAnnotationLayer, IntervalAnnotationLayer, LegendState, SupersetTheme, TimeseriesAnnotationLayer, TimeseriesDataRecord, ValueFormatter } from '@superset-ui/core';
import type { LineStyleOption, OptionName } from 'echarts/types/src/util/types';
import type { SeriesOption } from 'echarts';
import { EchartsTimeseriesSeriesType, ForecastSeriesEnum, LegendOrientation, OrientationType, StackType } from '../types';
export declare const getBaselineSeriesForStream: (series: [
    string | number,
    number
][][], seriesType: EchartsTimeseriesSeriesType) => {
    data: any;
    name: string;
    stack: string;
    stackStrategy: "all";
    type: "line";
    lineStyle: {
        opacity: number;
    };
    tooltip: {
        show: boolean;
    };
    silent: boolean;
    showSymbol: boolean;
    areaStyle: {
        opacity: number;
    };
    step: EchartsTimeseriesSeriesType.Start | EchartsTimeseriesSeriesType.Middle | EchartsTimeseriesSeriesType.End | undefined;
    smooth: boolean;
};
export declare function transformSeries(series: SeriesOption, colorScale: CategoricalColorScale, colorScaleKey: string, opts: {
    area?: boolean;
    connectNulls?: boolean;
    filterState?: FilterState;
    seriesContexts?: {
        [key: string]: ForecastSeriesEnum[];
    };
    markerEnabled?: boolean;
    markerSize?: number;
    areaOpacity?: number;
    seriesType?: EchartsTimeseriesSeriesType;
    stack?: StackType;
    stackIdSuffix?: string;
    yAxisIndex?: number;
    showValue?: boolean;
    onlyTotal?: boolean;
    legendState?: LegendState;
    formatter?: ValueFormatter;
    totalStackedValues?: number[];
    showValueIndexes?: number[];
    thresholdValues?: number[];
    richTooltip?: boolean;
    seriesKey?: OptionName;
    sliceId?: number;
    isHorizontal?: boolean;
    lineStyle?: LineStyleOption;
    queryIndex?: number;
    timeCompare?: string[];
    timeShiftColor?: boolean;
}): SeriesOption | undefined;
export declare function transformFormulaAnnotation(layer: FormulaAnnotationLayer, data: TimeseriesDataRecord[], xAxisCol: string, xAxisType: AxisType, colorScale: CategoricalColorScale, sliceId?: number, orientation?: OrientationType): SeriesOption;
export declare function transformIntervalAnnotation(layer: IntervalAnnotationLayer, data: TimeseriesDataRecord[], annotationData: AnnotationData, colorScale: CategoricalColorScale, theme: SupersetTheme, sliceId?: number, orientation?: OrientationType): SeriesOption[];
export declare function transformEventAnnotation(layer: EventAnnotationLayer, data: TimeseriesDataRecord[], annotationData: AnnotationData, colorScale: CategoricalColorScale, theme: SupersetTheme, sliceId?: number, orientation?: OrientationType): SeriesOption[];
export declare function transformTimeseriesAnnotation(layer: TimeseriesAnnotationLayer, markerSize: number, data: TimeseriesDataRecord[], annotationData: AnnotationData, colorScale: CategoricalColorScale, sliceId?: number, orientation?: OrientationType): SeriesOption[];
export declare function getPadding(showLegend: boolean, legendOrientation: LegendOrientation, addYAxisTitleOffset: boolean, zoomable: boolean, margin?: string | number | null, addXAxisTitleOffset?: boolean, yAxisTitlePosition?: string, yAxisTitleMargin?: number, xAxisTitleMargin?: number, isHorizontal?: boolean): {
    bottom: number;
    left: number;
    right: number;
    top: number;
};
//# sourceMappingURL=transformers.d.ts.map