import { groupBy as _groupBy, isNumber, transform } from 'lodash';
function getMetricValue(datum, metric) {
    return isNumber(datum[metric]) ? datum[metric] : 0;
}
export function treeBuilder(data, groupBy, metric, secondaryMetric) {
    const [curGroupBy, ...restGroupby] = groupBy;
    const curData = _groupBy(data, curGroupBy);
    return transform(curData, (result, value, key) => {
        const name = curData[key][0][curGroupBy];
        if (!restGroupby.length) {
            (value ?? []).forEach(datum => {
                const metricValue = getMetricValue(datum, metric);
                const secondaryValue = secondaryMetric
                    ? getMetricValue(datum, secondaryMetric)
                    : metricValue;
                const item = {
                    name,
                    value: metricValue,
                    secondaryValue,
                    groupBy: curGroupBy,
                };
                result.push(item);
            });
        }
        else {
            const children = treeBuilder(value, restGroupby, metric, secondaryMetric);
            const metricValue = children.reduce((prev, cur) => prev + cur.value, 0);
            const secondaryValue = secondaryMetric
                ? children.reduce((prev, cur) => prev + cur.secondaryValue, 0)
                : metricValue;
            result.push({
                name,
                children,
                value: metricValue,
                secondaryValue,
                groupBy: curGroupBy,
            });
        }
    }, []);
}
//# sourceMappingURL=treeBuilder.js.map